/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

void auto_completion_add_url (gchar *url);
void auto_completion_reset (void);
gchar *auto_completion_complete_url (gchar *prefix);
gchar *auto_completion_complete_url_extended (gchar *prefix, gboolean suggest);
void auto_completion_display (GaleonWindow *window, GtkWidget *entry);
void auto_completion_display_alternatives (GaleonWindow *window,
					   GtkWidget *entry);

